@@ -6,7 +6,7 @@ require     Tk::Canvas;
 use strict;use warnings;use utf8;
 use         Tk;
 use         Carp;
-our $VERSION     = '1.6';my $d8VS='H78MEDIC';
+our $VERSION     = '1.8';my $d8VS='H79M9Rot';
 @Tk::AbstractCanvas::ISA = qw(Tk::Derived Tk::Canvas); Construct Tk::Widget 'AbstractCanvas';
 sub Tk::Widget::ScrlACnv { shift->Scrolled('AbstractCanvas'=>@_) }
 my %_can_rotate_about_center = ( # If objects can't rotate about their center, their center can at least rotate about another point on the canvas.
@@ -604,8 +604,8 @@ Tk::AbstractCanvas - Canvas with Abstract center, zoom, and rotate methods
 
 =head1 VERSION
 
-This documentation refers to version 1.6 of Tk::AbstractCanvas, which was released on
-Sat Jul  8 14:13:18:12 -0500 2017.
+This documentation refers to version 1.8 of Tk::AbstractCanvas, which was released on
+Sun Jul  9 09:27:50:55 -0500 2017.
 
 =head1 SYNOPSIS
 
@@ -955,8 +955,6 @@ coordinates.
 
 =over 2
 
-=item - fix grid item placed in AC to do something appropriate from Josef Wolf 8 years ago at HTTPS://RT.CPAN.Org/Ticket/Display.html?id=46655
-
 =item - add Math::Geometry::Planar and others to polygonize, find_CM, test intersections, etc.
 
 =item - maybe include Graph::Easy and some file serialization like DiagEMT XML but maybe more like a .Hrc format for the future
@@ -974,6 +972,12 @@ Revision history for Perl extension Tk::AbstractCanvas:
 
 =over 2
 
+=item - 1.8 H79M9Rot Sun Jul  9 09:27:50:55 -0500 2017
+
+* added test skipping in 02acnv.t to resolve L<HTTPS://RT.CPAN.Org/Ticket/Display.html?id=122405>. (Thanks again Slaven!)
+
+* removed broken Build.PL         to resolve L<HTTPS://RT.CPAN.Org/Ticket/Display.html?id=122404>. (Thank you,   Slaven.)
+
 =item - 1.6 H78MEDIC Sat Jul  8 14:13:18:12 -0500 2017
 
 * cleaned up examples and tested that grid works from L<HTTPS://RT.CPAN.Org/Ticket/Display.html?id=46655>. (Thanks Josef!)
@@ -1014,7 +1018,7 @@ Please report any bugs or feature requests to   bug-Tk-AbstractCanvas at RT.CPAN
 
 =head1 SUPPORT
 
-You can find documentation for this module with the perldoc command.
+You can find documentation for this module with the perldoc command (after it is installed).
 
   `perldoc Tk::AbstractCanvas`
 
@@ -1032,7 +1036,7 @@ You can also look for information at:
 
   HTTPS://CPANRatings.Perl.Org/d/Tk-AbstractCanvas
 
-    Search  CPAN
+    Search CPAN
 
   HTTP://Search.CPAN.Org/dist/Tk-AbstractCanvas
 
